## AUTHORS

  * Michael Kohn (2008-2011, original author of libkohn-avi)

  * Robin Hahling "Rolinh" <robin.hahling@gw-computing.net> (2013, gwavi fork
    of libkohn-avi)

<!-- vim: set filetype=markdown textwidth=80 -->
